@@ -36,7 +36,8 @@ recommended_programs = {'qemu': [('qemu-kvm', 'kvm'), ('qemu-img',),
                         'openvswitch': [],
                         'lvsb': [('semanage',), ('getfattr',), ('restorecon',), ('virt-sandbox')],
                         'v2v': [],
-                        'libguestfs': [('perl',)]}
+                        'libguestfs': [('perl',)],
+                        'virttools': []}
 
 mandatory_programs = {'qemu': basic_program_requirements + ['gcc'],
                       'spice': basic_program_requirements + ['gcc'],
@@ -44,7 +45,11 @@ mandatory_programs = {'qemu': basic_program_requirements + ['gcc'],
                       'openvswitch': basic_program_requirements,
                       'lvsb': ['virt-sandbox', 'virt-sandbox-service', 'virsh'],
                       'v2v': basic_program_requirements,
-                      'libguestfs': basic_program_requirements}
+                      'libguestfs': basic_program_requirements,
+                      'virttools': basic_program_requirements + ['virt-install',
+                                                                 'virt-clone',
+                                                                 'virt-manager',
+                                                                 'virt-xml']}
 
 mandatory_headers = {'qemu': ['Python.h', 'types.h', 'socket.h', 'unistd.h'],
                      'spice': [],
@@ -52,7 +57,8 @@ mandatory_headers = {'qemu': ['Python.h', 'types.h', 'socket.h', 'unistd.h'],
                      'openvswitch': [],
                      'v2v': [],
                      'lvsb': [],
-                     'libguestfs': []}
+                     'libguestfs': [],
+                     'virttools': []}
 
 first_subtest = {'qemu': ['unattended_install', 'steps'],
                  'spice': ['unattended_install', 'steps'],
@@ -60,7 +66,8 @@ first_subtest = {'qemu': ['unattended_install', 'steps'],
                  'openvswitch': ['unattended_install'],
                  'v2v': ['unattended_install'],
                  'libguestfs': ['unattended_install'],
-                 'lvsb': []}
+                 'lvsb': [],
+                 'virttools': []}
 
 last_subtest = {'qemu': ['shutdown'],
                 'spice': ['shutdown'],
@@ -68,7 +75,8 @@ last_subtest = {'qemu': ['shutdown'],
                 'openvswitch': ['shutdown'],
                 'v2v': ['shutdown'],
                 'libguestfs': ['shutdown'],
-                'lvsb': []}
+                'lvsb': [],
+                'virttools': []}
 
 test_filter = ['__init__', 'cfg', 'dropin.py']
 
