@@ -606,15 +606,15 @@ def _substitution(value, d):
     if "$" in value:
         start = 0
         st = ""
+        d_flat = _drop_suffixes(d)
         try:
             match = match_substitute.search(value, start)
             while match:
-                d_flat = _drop_suffixes(d)
-                val = eval(match.group(1), None, d_flat)
+                val = d_flat[match.group(1)]
                 st += value[start:match.start()] + str(val)
                 start = match.end()
                 match = match_substitute.search(value, start)
-        except Exception:
+        except KeyError:
             pass
         st += value[start:len(value)]
         return st
@@ -947,7 +947,8 @@ class LDel(LOperators):
         exp = re.compile("%s$" % self.name)
         keys_to_del = collections.deque()
         for key in d:
-            if key not in _reserved_keys and exp.match(key):
+            keystr = "".join(key) if isinstance(key, tuple) else key
+            if key not in _reserved_keys and exp.match(keystr):
                 keys_to_del.append(key)
         for key in keys_to_del:
             del d[key]
