@@ -991,7 +991,7 @@ def preprocess(test, params, env):
             try:
                 path.find_command(cmd)
             except path.CmdNotFoundError as msg:
-                raise exceptions.TestSkipError(msg.message)
+                raise exceptions.TestSkipError(msg)
 
     _setup_manager.initialize(test, params, env)
     _setup_manager.register(test_setup.UlimitConfig)
@@ -1014,9 +1014,11 @@ def preprocess(test, params, env):
             # By default log the info level
             log_level = params.get("libvirtd_debug_level", "2")
             log_file = params.get("libvirtd_debug_file", "")
+            log_filters = params.get("libvirtd_debug_filters", "%s:*" % log_level)
             libvirtd_debug_log = test_setup.LibvirtdDebugLog(test,
                                                              log_level,
-                                                             log_file)
+                                                             log_file,
+                                                             log_filters)
             libvirtd_debug_log.enable()
 
     setup_pb = False
@@ -1277,7 +1279,7 @@ def preprocess(test, params, env):
             libvirtd_inst.restart()
 
     if params.get("setup_thp") == "yes":
-        thp = test_setup.TransparentHugePageConfig(test, params)
+        thp = test_setup.TransparentHugePageConfig(test, params, env)
         thp.setup()
 
     if params.get("setup_ksm") == "yes":
@@ -1758,7 +1760,7 @@ def postprocess(test, params, env):
 
     if params.get("setup_thp") == "yes":
         try:
-            thp = test_setup.TransparentHugePageConfig(test, params)
+            thp = test_setup.TransparentHugePageConfig(test, params, env)
             thp.cleanup()
         except Exception as details:
             err += "\nTHP cleanup: %s" % str(details).replace('\\n', '\n  ')
@@ -1882,12 +1884,14 @@ def postprocess(test, params, env):
     if params.get("verify_host_dmesg", "yes") == "yes":
         dmesg_log_file = params.get("host_dmesg_logfile", "host_dmesg.log")
         level = params.get("host_dmesg_level", 3)
+        expected_host_dmesg = params.get("expected_host_dmesg", "")
         ignore_result = params.get("host_dmesg_ignore", "no") == "yes"
         dmesg_log_file = utils_misc.get_path(test.debugdir, dmesg_log_file)
         try:
             utils_misc.verify_dmesg(dmesg_log_file=dmesg_log_file,
                                     ignore_result=ignore_result,
-                                    level_check=level)
+                                    level_check=level,
+                                    expected_dmesg=expected_host_dmesg)
         except exceptions.TestFail as details:
             err += "\nHost dmesg verification failed: %s" % details
 
