@@ -24,6 +24,7 @@ from virttest import data_dir
 from virttest import utils_package
 from virttest.staging import service
 
+LOG = logging.getLogger('avocado.' + __name__)
 
 ISCSI_CONFIG_FILE = "/etc/iscsi/initiatorname.iscsi"
 
@@ -135,8 +136,8 @@ def iscsi_node_del(target_name=None):
                 process.system(cmd, ignore_status=True)
                 break
         if not cmd:
-            logging.error("The target '%s' for delete is not in target node"
-                          " record", target_name)
+            LOG.error("The target '%s' for delete is not in target node"
+                      " record", target_name)
     else:
         for node_tup in node_list:
             cmd = "iscsiadm -m node -o delete -T %s " % node_tup[1]
@@ -164,7 +165,7 @@ def iscsi_logout(target_name=None):
         # This failure makes no sense when target name is not specified
         stderr = detail.result.stderr_text
         if not target_name and 'No matching sessions' in stderr:
-            logging.info("%s: %s", detail, stderr)
+            LOG.info("%s: %s", detail, stderr)
         else:
             raise
 
@@ -186,7 +187,7 @@ def iscsi_discover(portal_ip):
 
     session = ""
     if "Invalid" in output:
-        logging.debug(output)
+        LOG.debug(output)
     else:
         session = output
     return session
@@ -208,6 +209,7 @@ class _IscsiComm(object):
         self.target = params.get("target")
         self.export_flag = False
         self.luns = None
+        self.iscsi_lun_attrs = params.get("iscsi_lun_attrs")
         self.restart_tgtd = 'yes' == params.get("restart_tgtd", "no")
         if params.get("portal_ip"):
             self.portal_ip = params.get("portal_ip")
@@ -226,7 +228,19 @@ class _IscsiComm(object):
         if self.chap_user and self.chap_passwd:
             self.chap_flag = True
 
-        if params.get("emulated_image"):
+        emulated_image = params.get("emulated_image")
+        if not emulated_image:
+            self.device = None
+            return
+
+        self.iscsi_backend = params.get("iscsi_backend")
+        if not self.iscsi_backend:
+            if emulated_image.startswith("/dev/"):
+                self.iscsi_backend = "block"
+            else:
+                self.iscsi_backend = "fileio"
+
+        if self.iscsi_backend == "fileio":
             self.initiator = None
             emulated_image = params.get("emulated_image")
             self.emulated_image = os.path.join(root_dir, emulated_image)
@@ -251,7 +265,8 @@ class _IscsiComm(object):
                 raise exceptions.TestError("Image size provided is not in valid"
                                            " format, specify proper units [K|M|G|T]")
         else:
-            self.device = None
+            self.emulated_image = emulated_image
+            self.device = "device.%s" % os.path.basename(self.emulated_image)
 
     def logged_in(self):
         """
@@ -275,7 +290,7 @@ class _IscsiComm(object):
         back up and set up the InitiatorName
         """
         if os.path.isfile("%s" % ISCSI_CONFIG_FILE):
-            logging.debug("Try to update iscsi initiatorname")
+            LOG.debug("Try to update iscsi initiatorname")
             # Don't override the backup file
             if not os.path.isfile("%s-%s" % (ISCSI_CONFIG_FILE, id)):
                 cmd = "mv %s %s-%s" % (ISCSI_CONFIG_FILE, ISCSI_CONFIG_FILE, id)
@@ -326,10 +341,10 @@ class _IscsiComm(object):
             try:
                 device_name = "/dev/%s" % device_name[0]
             except IndexError:
-                logging.error(
+                LOG.error(
                     "Can not find target '%s' after login.", self.target)
         else:
-            logging.error("Session is not logged in yet.")
+            LOG.error("Session is not logged in yet.")
         return device_name
 
     def set_chap_auth_initiator(self):
@@ -345,7 +360,7 @@ class _IscsiComm(object):
             try:
                 process.system(cmd)
             except process.CmdError:
-                logging.error("Fail to set CHAP authentication for initiator")
+                LOG.error("Fail to set CHAP authentication for initiator")
 
     def logout(self):
         """
@@ -372,7 +387,7 @@ class _IscsiComm(object):
             if path.find_command("targetcli"):
                 cmd = "targetcli clearconfig confirm=true"
                 if process.system(cmd, shell=True) != 0:
-                    logging.error("targetcli configuration unable to clear")
+                    LOG.error("targetcli configuration unable to clear")
 
 
 class IscsiTGT(_IscsiComm):
@@ -427,11 +442,11 @@ class IscsiTGT(_IscsiComm):
             cmd += " --password %s" % self.chap_passwd
             process.system(cmd)
         except process.CmdError as err:
-            logging.error("Fail to add account: %s", err)
+            LOG.error("Fail to add account: %s", err)
 
         # Check the new add account exist
         if self.chap_user not in self.get_chap_accounts():
-            logging.error("Can't find account %s" % self.chap_user)
+            LOG.error("Can't find account %s" % self.chap_user)
 
     def delete_chap_account(self):
         """
@@ -465,8 +480,8 @@ class IscsiTGT(_IscsiComm):
         if self.chap_user not in self.get_chap_accounts():
             self.add_chap_account()
         if self.chap_user in self.get_target_account_info():
-            logging.debug("Target %s already has account %s", self.target,
-                          self.chap_user)
+            LOG.debug("Target %s already has account %s", self.target,
+                      self.chap_user)
         else:
             cmd = "tgtadm --lld iscsi --op bind --mode account"
             cmd += " --tid %s --user %s" % (self.emulated_id, self.chap_user)
@@ -492,7 +507,7 @@ class IscsiTGT(_IscsiComm):
             restart_tgtd()
             output = process.run(cmd).stdout_text
         if not re.findall("%s$" % self.target, output, re.M):
-            logging.debug("Need to export target in host")
+            LOG.debug("Need to export target in host")
 
             # Set selinux to permissive mode to make sure iscsi target
             # export successfully
@@ -527,7 +542,7 @@ class IscsiTGT(_IscsiComm):
         # Create a LUN with emulated image
         if re.findall(self.emulated_image, output, re.M):
             # Exist already
-            logging.debug("Exported image already exists.")
+            LOG.debug("Exported image already exists.")
             self.export_flag = True
         else:
             tgt_str = re.search(r'.*(Target\s+\d+:\s+%s\s*.*)$' % self.target,
@@ -598,7 +613,7 @@ class IscsiLIO(_IscsiComm):
                 try:
                     target = re.findall("iqn[\.]\S+:\S+", line)[0]
                 except IndexError:
-                    logging.info("No found target in %s", line)
+                    LOG.info("No found target in %s", line)
                     continue
             else:
                 continue
@@ -685,21 +700,22 @@ class IscsiLIO(_IscsiComm):
         Export target in localhost for emulated iscsi
         """
         selinux_mode = None
-
-        # create image disk
-        if not os.path.isfile(self.emulated_image):
-            process.system(self.create_cmd)
-        else:
-            emulated_image_size = os.path.getsize(self.emulated_image) // 1024
-            if emulated_image_size != self.emulated_expect_size:
-                # No need to remove, rebuild is fine
+        if self.iscsi_backend == "fileio":
+            # create image disk
+            if not os.path.isfile(self.emulated_image):
                 process.system(self.create_cmd)
+            else:
+                emulated_image_size = os.path.getsize(
+                    self.emulated_image) // 1024
+                if emulated_image_size != self.emulated_expect_size:
+                    # No need to remove, rebuild is fine
+                    process.system(self.create_cmd)
 
         # confirm if the target exists and create iSCSI target
         cmd = "targetcli ls /iscsi 1"
         output = process.run(cmd).stdout_text
         if not re.findall("%s$" % self.target, output, re.M):
-            logging.debug("Need to export target in host")
+            LOG.debug("Need to export target in host")
 
             # Set selinux to permissive mode to make sure
             # iscsi target export successfully
@@ -715,17 +731,22 @@ class IscsiLIO(_IscsiComm):
             #     (lvcreate -name lv_iscsi -size 1G vg)
             # 2) Create a fileio backstore,
             #    which enables the local file system cache.
-            #
-            # This class Only works for emulated iscsi device,
-            # So fileio backstore is enough and safe.
 
-            # Create a fileio backstore
-            device_cmd = ("targetcli /backstores/fileio/ create %s %s" %
-                          (self.device, self.emulated_image))
+            # Create a backstore
+            device_cmd = ("targetcli /backstores/%s/ create %s %s" %
+                          (self.iscsi_backend, self.device,
+                           self.emulated_image))
             output = process.run(device_cmd).stdout_text
-            if "Created fileio" not in output:
-                raise exceptions.TestFail("Failed to create fileio %s. (%s)" %
-                                          (self.device, output))
+            if "Created %s" % self.iscsi_backend not in output:
+                raise exceptions.TestFail("Failed to create %s %s. (%s)" %
+                                          (self.iscsi_backend, self.device,
+                                           output))
+
+            # Set attribute
+            if self.iscsi_lun_attrs:
+                attr_cmd = "targetcli /backstores/%s/%s set attribute %s" % (
+                    self.iscsi_backend, self.device, self.iscsi_lun_attrs)
+                process.system(attr_cmd)
 
             # Create an IQN with a target named target_name
             target_cmd = "targetcli /iscsi/ create %s" % self.target
@@ -758,7 +779,8 @@ class IscsiLIO(_IscsiComm):
                                               output)
             # Create lun
             lun_cmd = "targetcli /iscsi/%s/tpg1/luns/ " % self.target
-            dev_cmd = "create /backstores/fileio/%s" % self.device
+            dev_cmd = "create /backstores/%s/%s" % (
+                self.iscsi_backend, self.device)
             output = process.run(lun_cmd + dev_cmd).stdout_text
             luns = re.findall(r"Created LUN (\d+).", output)
             if not luns:
@@ -780,7 +802,7 @@ class IscsiLIO(_IscsiComm):
 
             self.export_flag = True
         else:
-            logging.info("Target %s has already existed!" % self.target)
+            LOG.info("Target %s has already existed!" % self.target)
 
         if self.chap_flag:
             # Set CHAP authentication on the exported target
@@ -801,7 +823,7 @@ class IscsiLIO(_IscsiComm):
                          "generate_node_acls=1",
                          "cache_dynamic_acls=1"))
             output = process.run(auth_cmd + attr_cmd).stdout_text
-            logging.info("Define access rights: %s" % output)
+            LOG.info("Define access rights: %s" % output)
             # Discovery the target
             self.portal_visible()
 
@@ -817,11 +839,11 @@ class IscsiLIO(_IscsiComm):
         """
         # Delete block
         if self.device is not None:
-            cmd = "targetcli /backstores/fileio ls"
+            cmd = "targetcli /backstores/%s ls" % self.iscsi_backend
             output = process.run(cmd).stdout_text
             if re.findall("%s" % self.device, output, re.M):
-                dev_del = ("targetcli /backstores/fileio/ delete %s"
-                           % self.device)
+                dev_del = ("targetcli /backstores/%s/ delete %s"
+                           % (self.iscsi_backend, self.device))
                 process.system(dev_del)
 
         # Delete IQN
@@ -862,8 +884,8 @@ class Iscsi(object):
         # Install linux iscsi target software targetcli
         iscsi_package = ["targetcli"]
         if not utils_package.package_install(iscsi_package):
-            logging.error("Failed to install targetcli trying with scsi-"
-                          "target-utils or tgt package")
+            LOG.error("Failed to install targetcli trying with scsi-"
+                      "target-utils or tgt package")
             # try with scsi target utils if targetcli is not available
             if ubuntu:
                 iscsi_package = ["tgt"]
