@@ -57,12 +57,15 @@ class Memory(base.UntypedDeviceBase):
 
         Properties:
 
-        size, node:
+        size, node, requested_size, current_size, block_size:
             int.
-        size_unit:
+        size_unit, requested_unit, current_unit, block_unit:
             string.
         """
-        __slots__ = ('size', 'size_unit', 'node', 'label')
+        __slots__ = ('size', 'size_unit', 'node', 'label',
+                     'requested_size', 'requested_unit',
+                     'current_size', 'current_unit',
+                     'block_size', 'block_unit', 'readonly')
 
         def __init__(self, virsh_instance=base.base.virsh):
             accessors.XMLElementInt('size',
@@ -74,6 +77,33 @@ class Memory(base.UntypedDeviceBase):
                                    parent_xpath='/',
                                    tag_name='size',
                                    attribute='unit')
+            accessors.XMLElementInt('requested_size',
+                                    self, parent_xpath='/',
+                                    tag_name='requested')
+            accessors.XMLAttribute(property_name="requested_unit",
+                                   libvirtxml=self,
+                                   forbidden=None,
+                                   parent_xpath='/',
+                                   tag_name='requested',
+                                   attribute='unit')
+            accessors.XMLElementInt('current_size',
+                                    self, parent_xpath='/',
+                                    tag_name='current')
+            accessors.XMLAttribute(property_name="current_unit",
+                                   libvirtxml=self,
+                                   forbidden=None,
+                                   parent_xpath='/',
+                                   tag_name='current',
+                                   attribute='unit')
+            accessors.XMLElementInt('block_size',
+                                    self, parent_xpath='/',
+                                    tag_name='block')
+            accessors.XMLAttribute(property_name="block_unit",
+                                   libvirtxml=self,
+                                   forbidden=None,
+                                   parent_xpath='/',
+                                   tag_name='block',
+                                   attribute='unit')
             accessors.XMLElementInt('node',
                                     self, parent_xpath='/',
                                     tag_name='node')
@@ -81,6 +111,8 @@ class Memory(base.UntypedDeviceBase):
                                      tag_name='label', subclass=self.Label,
                                      subclass_dargs={
                                          'virsh_instance': virsh_instance})
+            accessors.XMLElementBool('readonly', self, parent_xpath='/',
+                                     tag_name='readonly')
             super(self.__class__, self).__init__(virsh_instance=virsh_instance)
             self.xml = '<target/>'
 
@@ -118,12 +150,16 @@ class Memory(base.UntypedDeviceBase):
 
         Properties:
 
-        pagesize:
-            int.
-        pagesize_unit, nodemask:
-            string.
+        pagesize: int, override the default host page size used for backing the memory device
+        pagesize_unit: str, the unit of pagesize
+        nodemask: str, override the default set of NUMA nodes where the memory would be allocated
+        path: str, the path in the host that backs the memory device in the guest
+        alignsize: int, the page size alignment used to mmap the address range for the backend path
+        alignsize_unit: str, the unit of alignsize
+        pmem:boolean, persistent memory feature is enabled
         """
-        __slots__ = ('pagesize', 'pagesize_unit', 'nodemask', 'path')
+        __slots__ = ('pagesize', 'pagesize_unit', 'nodemask', 'path',
+                     'alignsize', 'alignsize_unit', 'pmem')
 
         def __init__(self, virsh_instance=base.base.virsh):
             accessors.XMLElementInt('pagesize',
@@ -141,6 +177,17 @@ class Memory(base.UntypedDeviceBase):
             accessors.XMLElementText('path',
                                      self, parent_xpath='/',
                                      tag_name='path')
+            accessors.XMLElementInt('alignsize',
+                                    self, parent_xpath='/',
+                                    tag_name='alignsize')
+            accessors.XMLAttribute(property_name="alignsize_unit",
+                                   libvirtxml=self,
+                                   forbidden=None,
+                                   parent_xpath='/',
+                                   tag_name='alignsize',
+                                   attribute='unit')
+            accessors.XMLElementBool('pmem', self, parent_xpath='/',
+                                     tag_name='pmem')
             super(self.__class__, self).__init__(virsh_instance=virsh_instance)
             self.xml = '<source/>'
 
