@@ -269,6 +269,15 @@ def _get_image_meta(image, params, root_dir):
             meta['file'].update({
                 k: v[1] for k, v in six.iteritems(mapping) if v[0]
             })
+    filters = params.get("image_filter_drivers", "").split()
+    # Stack them reversed, so the first filter on the list
+    # will be on top of the rest of filters
+    for img_filter in filters[::-1]:
+        tmp_meta = collections.OrderedDict()
+        tmp_meta["file"] = meta
+        meta = tmp_meta
+        filter_cfg = _FilterConfigGatherer.gather(img_filter, params)
+        meta.update(filter_cfg)
 
     return meta
 
@@ -347,6 +356,53 @@ def get_image_repr(image, params, root_dir, representation=None):
     return func(image, params, root_dir)
 
 
+class _FilterConfigGatherer(object):
+    """ This class can be used to gather filter-specific configuration
+        from test params to generate fully-valid image_meta dicts.
+        The filter-specific image_meta should be obtained by calling
+        the gather class method.
+        This class should contain as much private methods as filters that
+        should be supported for image_meta generation. In other words,
+        each supported filter should contain a _<filter_type> implemented
+        in this class as well as a "<filter_type>": <cfg_gather_func> key/value
+        entry in the _config_gatherers dict from the gather method.
+    """
+
+    @classmethod
+    def gather(cls, filter_name, params):
+        """ Gathers filter-specific config from params and collects
+            them properly on an OrderedDict.
+            This method is in charge of calling the appropriate private
+            class method
+            :param filter_name: Name/id of the filter for which data is being
+                                gathered
+            :type filter_name: str
+            :param params: Collection of parameters from which data will be
+                           gathered
+            :type params: Ordered Dict
+            :return: Ordered Dict
+        """
+        _config_gatherers = {"compress": cls._compress}
+        filter_params = params.object_params(filter_name)
+        filter_type = filter_params.get("image_filter_driver_type")
+        # Calls the adequate function for us
+        try:
+            gather_func = _config_gatherers[filter_type]
+        except KeyError:
+            # Filter is not supported
+            raise NotImplementedError("Image configuration meta generation "
+                                      "support hasn't been implemented for "
+                                      f"{filter_type} filter yet.")
+        return gather_func(filter_params)
+
+    @staticmethod
+    def _compress(params):
+        """ Gives an empty OrderedDict (as compress filter doesn't have
+            specific attributes related to the filter)
+        """
+        return collections.OrderedDict({"driver": "compress"})
+
+
 class _ParameterAssembler(string.Formatter):
     """
     Command line parameter assembler.
@@ -1096,6 +1152,129 @@ class QemuImg(storage.QemuImg):
 
         process.run(cmd)
 
+    def bitmap_add(self, bitmap_name):
+        """
+        Add a bitmap to a image.
+
+        :param bitmap_name: The name of the bitmap
+        """
+
+        bitmap_params = self.params.object_params(bitmap_name)
+        granularity = bitmap_params.get('bitmap_granularity')
+
+        cmd = self.image_cmd
+        if self.image_format == 'qcow2':
+            cmd += " bitmap --add -f %s %s %s" % (
+                self.image_format, self.image_filename, bitmap_name)
+            if granularity:
+                cmd += ' -g %s' % granularity
+        else:
+            raise exceptions.TestError(
+                "Image format %s is not supported, check please." %
+                self.image_format)
+
+        process.run(cmd)
+
+    def bitmap_remove(self, bitmap_name):
+        """
+        Remove a bitmap from a image.
+
+        :param bitmap_name: The name of the bitmap
+        """
+
+        cmd = self.image_cmd
+        if self.image_format == 'qcow2':
+            cmd += " bitmap --remove -f %s %s %s" % (
+                self.image_format, self.image_filename, bitmap_name)
+        else:
+            raise exceptions.TestError(
+                "Image format %s is not supported, check please." %
+                self.image_format)
+
+        process.run(cmd)
+
+    def bitmap_clear(self, bitmap_name):
+        """
+        Clear a bitmap of a image.
+
+        :param bitmap_name: The name of the bitmap
+        """
+
+        cmd = self.image_cmd
+        if self.image_format == 'qcow2':
+            cmd += " bitmap --clear -f %s %s %s" % (
+                self.image_format, self.image_filename, bitmap_name)
+        else:
+            raise exceptions.TestError(
+                "Image format %s is not supported, check please." %
+                self.image_format)
+
+        process.run(cmd)
+
+    def bitmap_enable(self, bitmap_name):
+        """
+        Enable a bitmap of a image.
+
+        :param bitmap_name: The name of the bitmap
+        """
+
+        cmd = self.image_cmd
+        if self.image_format == 'qcow2':
+            cmd += " bitmap --enable -f %s %s %s" % (
+                self.image_format, self.image_filename, bitmap_name)
+        else:
+            raise exceptions.TestError(
+                "Image format %s is not supported, check please." %
+                self.image_format)
+
+        process.run(cmd)
+
+    def bitmap_disable(self, bitmap_name):
+        """
+        Disable a bitmap of a image.
+
+        :param bitmap_name: The name of the bitmap
+        """
+
+        cmd = self.image_cmd
+        if self.image_format == 'qcow2':
+            cmd += " bitmap --disable -f %s %s %s" % (
+                self.image_format, self.image_filename, bitmap_name)
+        else:
+            raise exceptions.TestError(
+                "Image format %s is not supported, check please." %
+                self.image_format)
+
+        process.run(cmd)
+
+    def bitmap_merge(self, params, root_dir, bitmap_name_source,
+                     bitmap_name_target, bitmap_image_source):
+        """
+        Merge a bitmap from source image to target image.
+
+        :param params: dictionary containing the test parameters
+        :param root_dir: Base directory for relative filenames
+        :param bitmap_name_source: The name of the bitmap for source image
+        :param bitmap_name_target: The name of the bitmap for target image
+        :param bitmap_image_source: The tag for source image
+        """
+
+        bitmap_source_params = params.object_params(bitmap_image_source)
+        bitmap_source_image = QemuImg(bitmap_source_params, root_dir,
+                                      bitmap_image_source)
+        cmd = self.image_cmd
+        if self.image_format == 'qcow2':
+            cmd += " bitmap --merge %s -b %s -F %s -f %s %s %s" % (
+                bitmap_name_source, bitmap_source_image.image_filename,
+                bitmap_source_image.image_format, self.image_format,
+                self.image_filename, bitmap_name_target)
+        else:
+            raise exceptions.TestError(
+                "Image format %s is not supported, check please." %
+                self.image_format)
+
+        process.run(cmd)
+
     def remove(self):
         """
         Remove an image file.
@@ -1338,13 +1517,15 @@ class QemuImg(storage.QemuImg):
 
         return result
 
-    def check(self, params, root_dir, force_share=False, output=None):
+    def check(self, params, root_dir, force_share=False, output=None,
+              check_repair=None):
         """
         Check an image using the appropriate tools for each virt backend.
 
         :param params: Dictionary containing the test parameters.
         :param root_dir: Base directory for relative filenames.
         :param output: The format of the output(json, human).
+        :param check_repair: Repair the image(leaks, all).
 
         :note: params should contain:
                image_name -- the name of the image file, without extension
@@ -1358,7 +1539,8 @@ class QemuImg(storage.QemuImg):
 
         cmd_dict = {"image_filename": image_filename,
                     "force_share": force_share,
-                    "output_format": output}
+                    "output_format": output,
+                    "check_repair": check_repair}
         if (self.encryption_config.key_secret
                 or self._need_auth_info(self.tag)):
             cmd_dict["image_filename"] = "'%s'" % get_image_json(
