@@ -9,7 +9,7 @@ path = sys.argv[1]
 size = int(sys.argv[2])
 
 if not os.path.isdir(os.path.dirname(path)):
-    os.mkdir(os.path.dirname(path))
+    os.makedirs(os.path.dirname(path))
 writefile = open(path, 'w')
 writefile.seek(1024 * 1024 * size)
 writefile.write('\x00')
