@@ -9,6 +9,8 @@ from avocado.utils import path
 
 from virttest import remote as remote_old
 
+LOG = logging.getLogger('avocado.' + __name__)
+
 
 def get_public_key(client_user=None):
     """
@@ -47,15 +49,15 @@ def get_public_key(client_user=None):
                        os.path.isfile(rsa_private_key_path))
 
     if has_rsa_keypair:
-        logging.info('RSA keypair found, using it')
+        LOG.info('RSA keypair found, using it')
         public_key_path = rsa_public_key_path
 
     elif has_dsa_keypair:
-        logging.info('DSA keypair found, using it')
+        LOG.info('DSA keypair found, using it')
         public_key_path = dsa_public_key_path
 
     else:
-        logging.info('Neither RSA nor DSA keypair found, creating RSA ssh key pair')
+        LOG.info('Neither RSA nor DSA keypair found, creating RSA ssh key pair')
         if os.environ.get('USER') != 'root':
             process.system('ssh-keygen -t rsa -q -N \"\" -f %s' %
                            rsa_private_key_path, shell=True)
@@ -100,16 +102,16 @@ def get_remote_public_key(session, public_key="rsa"):
     has_rsa_keypair = rsa_public_s == 0 and rsa_private_s == 0
 
     if has_dsa_keypair and public_key == "dsa":
-        logging.info('DSA keypair found on %s, using it', session)
+        LOG.info('DSA keypair found on %s, using it', session)
         public_key_path = dsa_public_key_path
 
     elif has_rsa_keypair and public_key == "rsa":
-        logging.info('RSA keypair found on %s, using it', session)
+        LOG.info('RSA keypair found on %s, using it', session)
         public_key_path = rsa_public_key_path
 
     else:
-        logging.info('Neither RSA nor DSA keypair found, '
-                     'creating %s ssh key pair' % public_key)
+        LOG.info('Neither RSA nor DSA keypair found, '
+                 'creating %s ssh key pair' % public_key)
         key_path = rsa_private_key_path
         public_key_path = rsa_public_key_path
         if public_key == "dsa":
@@ -137,8 +139,8 @@ def setup_ssh_key(hostname, user, password, port=22, client_user=None):
                         user to login into the server
     :type client_user: str
     """
-    logging.debug('Performing SSH key setup on %s:%d as %s.' %
-                  (hostname, port, user))
+    LOG.debug('Performing SSH key setup on %s:%d as %s.' %
+              (hostname, port, user))
 
     try:
         session = remote.remote_login(client='ssh', host=hostname,
@@ -151,10 +153,10 @@ def setup_ssh_key(hostname, user, password, port=22, client_user=None):
         session.cmd("echo '%s' >> ~/.ssh/authorized_keys; " %
                     public_key)
         session.cmd('chmod 600 ~/.ssh/authorized_keys')
-        logging.debug('SSH key setup complete.')
+        LOG.debug('SSH key setup complete.')
 
     except Exception:
-        logging.debug('SSH key setup has failed.')
+        LOG.debug('SSH key setup has failed.')
 
     finally:
         try:
@@ -182,8 +184,8 @@ def setup_remote_ssh_key(hostname1, user1, password1,
     :param config_options: list of options eg: ["StrictHostKeyChecking=no"]
     :type config_options: list of str
     """
-    logging.debug('Performing SSH key setup on %s:%d as %s.' %
-                  (hostname1, port, user1))
+    LOG.debug('Performing SSH key setup on %s:%d as %s.' %
+              (hostname1, port, user1))
 
     try:
         session1 = remote.remote_login(client='ssh', host=hostname1, port=port,
@@ -214,9 +216,9 @@ def setup_remote_ssh_key(hostname1, user1, password1,
         session2.cmd_output("echo '%s' >> ~/.ssh/authorized_keys; " %
                             public_key)
         session2.cmd_output('chmod 600 ~/.ssh/authorized_keys')
-        logging.debug('SSH key setup on %s complete.', session2)
+        LOG.debug('SSH key setup on %s complete.', session2)
     except Exception as err:
-        logging.debug('SSH key setup has failed: %s', err)
+        LOG.debug('SSH key setup has failed: %s', err)
         try:
             session1.close()
             session2.close()
@@ -242,13 +244,13 @@ def setup_remote_known_hosts_file(client_ip, server_ip,
     :rtype: remote_old.RemoteFile
     :return: None if required command is not found
     """
-    logging.debug('Performing known_hosts file setup on %s from %s.' %
-                  (server_ip, client_ip))
+    LOG.debug('Performing known_hosts file setup on %s from %s.' %
+              (server_ip, client_ip))
     abs_path = ""
     try:
         abs_path = path.find_command("ssh-keyscan")
     except path.CmdNotFoundError as err:
-        logging.debug("Failed to find the command: %s", err)
+        LOG.debug("Failed to find the command: %s", err)
         return None
 
     cmd = "%s %s" % (abs_path, client_ip)
