@@ -709,7 +709,8 @@ class TCPConnection(ConnectionBase):
                  'remote_libvirtdconf', 'sasl_allowed_users',
                  'auth_tcp', 'listen_addr', 'remote_saslconf',
                  'remote_libvirtd_tcp_socket', 'client_hosts',
-                 'daemon_conf', 'daemon_socket_conf')
+                 'daemon_conf', 'daemon_socket_conf',
+                 'tcp_min_ssf')
 
     def __init__(self, *args, **dargs):
         """
@@ -727,6 +728,7 @@ class TCPConnection(ConnectionBase):
         init_dict['sasl_type'] = init_dict.get('sasl_type', 'gssapi')
         init_dict['listen_addr'] = init_dict.get('listen_addr')
         init_dict['sasl_allowed_users'] = init_dict.get('sasl_allowed_users')
+        init_dict['tcp_min_ssf'] = init_dict.get('tcp_min_ssf')
         super(TCPConnection, self).__init__(init_dict)
 
         if utils_split_daemons.is_modular_daemon():
@@ -832,6 +834,7 @@ class TCPConnection(ConnectionBase):
         server_session = self.server_session
         # require a list data type
         sasl_allowed_users = self.sasl_allowed_users
+        tcp_min_ssf = self.tcp_min_ssf
         listen_addr = self.listen_addr
         pattern_to_repl = {}
         if not libvirt_version.version_compare(5, 6, 0, server_session):
@@ -857,6 +860,9 @@ class TCPConnection(ConnectionBase):
         if listen_addr:
             pattern_to_repl[r".*listen_addr\s*=.*"] = \
                 "listen_addr='%s'" % (listen_addr)
+        if tcp_min_ssf:
+            pattern_to_repl[r".*tcp_min_ssf\s*=.*"] = \
+                "tcp_min_ssf=%s" % (tcp_min_ssf)
         self.remote_libvirtdconf.sub_else_add(pattern_to_repl)
 
         # edit the /etc/sasl2/libvirt.conf to change sasl method
@@ -1555,7 +1561,10 @@ class TLSConnection(ConnectionBase):
         if self.sasl_type == 'digest-md5':
             utils_package.package_install('cyrus-sasl-md5', session=client_session)
         for target_dir in [self.pki_CA_dir, self.libvirt_pki_private_dir]:
-            if not os.path.exists(target_dir):
+            # Check dir if exists
+            cmd = "ls %s" % target_dir
+            status, output = client_session.cmd_status_output(cmd)
+            if status:
                 cmd = "mkdir -p %s" % target_dir
                 status, output = client_session.cmd_status_output(cmd)
                 if status:
@@ -1822,7 +1831,7 @@ class UNIXConnection(ConnectionBase):
         init_dict['restart_libvirtd'] = init_dict.get(
             'restart_libvirtd', 'yes')
         init_dict['sasl_allowed_username_list'] = init_dict.get(
-            'sasl_allowed_username_list', '["root/admin" ]')
+            'sasl_allowed_username_list')
         init_dict['traditional_mode'] = init_dict.get(
             'traditional_mode', 'no')
         init_dict['run_on_remote'] = init_dict.get('run_on_remote', 'no')
@@ -1849,13 +1858,20 @@ class UNIXConnection(ConnectionBase):
         client_session = self.client_session
         self.libvirt_ver = libvirt_version.version_compare(5, 6, 0, client_session)
 
+        if utils_split_daemons.is_modular_daemon():
+            daemon_conf = "/etc/libvirt/virtqemud.conf"
+            daemon_socket = "/usr/lib/systemd/system/virtqemud.socket"
+        else:
+            daemon_conf = "/etc/libvirt/libvirtd.conf"
+            daemon_socket = "/usr/lib/systemd/system/libvirtd.socket"
+
         self.client_libvirtdconf = remote_old.RemoteFile(
             address=session_ip,
             client='scp',
             username=session_user,
             password=session_pwd,
             port='22',
-            remote_path='/etc/libvirt/libvirtd.conf')
+            remote_path=daemon_conf)
 
         self.client_libvirtd_socket = remote_old.RemoteFile(
             address=session_ip,
@@ -1863,7 +1879,7 @@ class UNIXConnection(ConnectionBase):
             username=session_user,
             password=session_pwd,
             port='22',
-            remote_path='/usr/lib/systemd/system/libvirtd.socket')
+            remote_path=daemon_socket)
 
         self.client_saslconf = remote_old.RemoteFile(
             address=session_ip,
@@ -1903,10 +1919,10 @@ class UNIXConnection(ConnectionBase):
                 current_session = sessions[1]
                 remote_runner = remote_old.RemoteRunner(session=current_session)
                 runner = remote_runner.run
-            libvirtd_service = utils_libvirtd.Libvirtd(session=current_session)
-            if self.libvirt_ver:
+            if utils_split_daemons.is_modular_daemon():
                 # For traditional mode, need unmask libvirtd*.socket
                 if traditional_mode == 'yes':
+                    runner("systemctl stop libvirtd")
                     runner("systemctl unmask libvirtd.socket")
                     runner("systemctl unmask libvirtd-admin.socket")
                     runner("systemctl unmask libvirtd-ro.socket")
@@ -1914,12 +1930,18 @@ class UNIXConnection(ConnectionBase):
                     runner("systemctl unmask libvirtd-tls.socket")
                 else:
                     runner("systemctl daemon-reload")
-                    runner("systemctl stop libvirtd.socket")
-                runner("systemctl stop libvirtd.service")
-                runner("systemctl start libvirtd.socket")
-                libvirtd_service.start()
+                    runner("systemctl stop virtqemud.socket")
+                    runner("systemctl stop virtqemud")
+                    runner("systemctl start virtqemud.socket")
+                    runner("systemctl reset-failed virtqemud")
+                    runner("systemctl start virtqemud")
             else:
-                libvirtd_service.restart()
+                runner("systemctl daemon-reload")
+                runner("systemctl stop libvirtd.socket")
+                runner("systemctl stop libvirtd")
+                runner("systemctl start libvirtd.socket")
+                runner("systemctl reset-failed libvirtd")
+                runner("systemctl start libvirtd")
             current_session.close()
         except (remote.LoginError, aexpect.ShellError,
                 process.CmdError) as detail:
@@ -2019,6 +2041,12 @@ class UNIXConnection(ConnectionBase):
                 pattern_to_repl = {r".*unix_sock_rw_perms\s*=.*":
                                    'unix_sock_rw_perms="%s"' % unix_sock_rw_perms}
                 self.client_libvirtdconf.sub_else_add(pattern_to_repl)
+        # edit the /etc/libvirt/libvirtd.conf to add sasl_allowed_username_list arg
+        if sasl_allowed_username_list:
+            pattern_to_repl = {r".*sasl_allowed_username_list\s*=.*":
+                               'sasl_allowed_username_list=%s'
+                               % sasl_allowed_username_list}
+            self.client_libvirtdconf.sub_else_add(pattern_to_repl)
         sessions = self.session_creator()
         pkg_dict = {'digest-md5': 'cyrus-sasl-md5', 'plain': 'cyrus-sasl-plain'}
         for current_session in sessions:
@@ -2073,31 +2101,36 @@ class UNIXConnection(ConnectionBase):
                     remote_runner = remote_old.RemoteRunner(
                         session=current_session)
                     runner = remote_runner.run
-                libvirtd_service = utils_libvirtd.Libvirtd(
-                    session=current_session)
-                if self.libvirt_ver:
+                if utils_split_daemons.is_modular_daemon():
                     # For traditional mode, need mask libvirtd*.socket
                     if traditional_mode == 'yes':
+                        runner("systemctl daemon-reload")
                         runner("systemctl stop libvirtd.socket")
                         runner("systemctl stop libvirtd-admin.socket")
                         runner("systemctl stop libvirtd-ro.socket")
                         runner("systemctl stop libvirtd-tcp.socket")
                         runner("systemctl stop libvirtd-tls.socket")
-                        libvirtd_service.stop()
                         runner("systemctl mask libvirtd.socket")
                         runner("systemctl mask libvirtd-admin.socket")
                         runner("systemctl mask libvirtd-ro.socket")
                         runner("systemctl mask libvirtd-tcp.socket")
                         runner("systemctl mask libvirtd-tls.socket")
-                        runner("systemctl daemon-reload")
+                        runner("systemctl reset-failed libvirtd")
+                        runner("systemctl start libvirtd")
                     else:
                         runner("systemctl daemon-reload")
-                        runner("systemctl stop libvirtd.socket")
-                        libvirtd_service.stop()
-                        runner("systemctl start libvirtd.socket")
-                    runner("systemctl start libvirtd.service")
+                        runner("systemctl stop virtqemud.socket")
+                        runner("systemctl stop virtqemud")
+                        runner("systemctl start virtqemud.socket")
+                        runner("systemctl reset-failed virtqemud")
+                        runner("systemctl start virtqemud")
                 else:
-                    libvirtd_service.restart()
+                    runner("systemctl daemon-reload")
+                    runner("systemctl stop libvirtd.socket")
+                    runner("systemctl stop libvirtd")
+                    runner("systemctl start libvirtd.socket")
+                    runner("systemctl reset-failed libvirtd")
+                    runner("systemctl start libvirtd")
                 current_session.close()
             except (remote.LoginError, aexpect.ShellError,
                     process.CmdError) as detail:
@@ -2332,3 +2365,31 @@ class UNIXSocketConnection(ConnectionBase):
         self.connect_to_unix_socket(tcp2unix_session, dest_pmsocat_path)
         self.add_firewall_ports(tcp2unix_session)
         LOG.debug("TCP2UNIX setup successfully.")
+
+
+def update_crypto_policy(value="DEFAULT", verbose=True, ignore_status=True, shell=True):
+    """
+    Update the crypto policy, see "man update-crypto-policies".
+
+    :param value: the policy value, see "man crypto-policies".
+    :param verbose: Whether to log the command run and stdout/stderr.
+    :param ignore_status: Whether to raise an exception when command returns
+                          =! 0 (False), or not (True).
+    :param shell: Whether to run the command on a subshell
+    """
+    cmd = "update-crypto-policies --set %s" % value
+    cmd_res = process.run(
+        cmd,
+        verbose=verbose,
+        ignore_status=ignore_status,
+        shell=shell)
+
+    cmd_get_policy = "update-crypto-policies --show"
+    val = process.run(
+        cmd_get_policy,
+        verbose=False,
+        ignore_status=True,
+        shell=True).stdout_text
+    LOG.info("Current crypto policy: %s", val)
+
+    return cmd_res
