@@ -23,6 +23,8 @@ try:
 except path.CmdNotFoundError:
     LIBVIRTD = None
 
+LOG = logging.getLogger('avocado.' + __name__)
+
 
 class Libvirtd(object):
 
@@ -30,15 +32,18 @@ class Libvirtd(object):
     Class to manage libvirtd service on host or guest.
     """
 
-    def __init__(self, service_name=None, session=None):
+    def __init__(self, service_name=None, session=None, all_daemons=False):
         """
         Initialize an service object for libvirtd.
 
         :params service_name: Service name such as virtqemud or libvirtd.
-            If service_name is None, all sub daemons will be operated when
-            modular daemon environment is enabled. Otherwise,if service_name is
-            a single string, only the given daemon/service will be operated.
+            If service_name is None or 'libvirt' and all_daemons is True,
+            all sub daemons will be operated when modular daemon environment is
+            enabled. Otherwise, if service_name is a single string, only the
+            given daemon/service will be operated.
         :params session: An session to guest or remote host.
+        :params all_daemons: Whether to operate all daemons when modular daemons
+            are enabled. It only works if service_name is None or 'libvirtd'.
         """
         self.session = session
         if self.session:
@@ -47,22 +52,25 @@ class Libvirtd(object):
         else:
             runner = process.run
 
+        self.all_daemons = all_daemons
         self.daemons = []
         self.service_list = []
 
         if LIBVIRTD is None:
-            logging.warning("Libvirtd service is not available in host, "
-                            "utils_libvirtd module will not function normally")
+            LOG.warning("Libvirtd service is not available in host, "
+                        "utils_libvirtd module will not function normally")
 
         self.service_name = "libvirtd" if not service_name else service_name
 
         if libvirt_version.version_compare(5, 6, 0, self.session):
             if utils_split_daemons.is_modular_daemon(session=self.session):
                 if self.service_name in ["libvirtd", "libvirtd.service"]:
-                    self.service_list = ['virtqemud', 'virtproxyd',
-                                         'virtnetworkd', 'virtinterfaced',
-                                         'virtnodedevd', 'virtsecretd',
-                                         'virtstoraged', 'virtnwfilterd']
+                    self.service_name = "virtqemud"
+                    if self.all_daemons:
+                        self.service_list = ['virtqemud', 'virtproxyd',
+                                             'virtnetworkd', 'virtinterfaced',
+                                             'virtnodedevd', 'virtsecretd',
+                                             'virtstoraged', 'virtnwfilterd']
                 elif self.service_name == "libvirtd.socket":
                     self.service_name = "virtqemud.socket"
                 elif self.service_name in ["libvirtd-tcp.socket", "libvirtd-tls.socket"]:
@@ -217,7 +225,7 @@ class LibvirtdSession(object):
         self.libvirtd_service = Libvirtd(service_name=self.service_exec)
         self.was_running = self.libvirtd_service.is_running()
         if self.was_running:
-            logging.debug('Stopping %s service', self.service_exec)
+            LOG.debug('Stopping %s service', self.service_exec)
             self.libvirtd_service.stop()
 
         self.logging_handler = logging_handler
@@ -285,7 +293,7 @@ class LibvirtdSession(object):
             self.gdb.set_callback(
                 callback_type, callback_func, callback_params)
         else:
-            logging.error("Only gdb session supports setting callback")
+            LOG.error("Only gdb session supports setting callback")
 
     def start(self, arg_str='', wait_for_working=True):
         """
@@ -315,7 +323,7 @@ class LibvirtdSession(object):
         if self.gdb:
             self.gdb.cont()
         else:
-            logging.error("Only gdb session supports continue")
+            LOG.error("Only gdb session supports continue")
 
     def kill(self):
         """
@@ -333,7 +341,7 @@ class LibvirtdSession(object):
         :param arg_str: Argument passing to the session
         :param wait_for_working: Whether wait for libvirtd finish loading
         """
-        logging.debug("Restarting %s session", self.service_exec)
+        LOG.debug("Restarting %s session", self.service_exec)
         self.kill()
         self.start(arg_str=arg_str, wait_for_working=wait_for_working)
 
@@ -343,7 +351,7 @@ class LibvirtdSession(object):
 
         :param timeout: Max wait time
         """
-        logging.debug('Waiting for %s to work', self.service_exec)
+        LOG.debug('Waiting for %s to work', self.service_exec)
         return utils_misc.wait_for(
             self.is_working,
             timeout=timeout,
@@ -356,7 +364,7 @@ class LibvirtdSession(object):
         if self.gdb:
             return self.gdb.back_trace()
         else:
-            logging.warning('Can not get back trace without gdb')
+            LOG.warning('Can not get back trace without gdb')
 
     def insert_break(self, break_func):
         """
@@ -367,7 +375,7 @@ class LibvirtdSession(object):
         if self.gdb:
             return self.gdb.insert_break(break_func)
         else:
-            logging.warning('Can not insert breakpoint without gdb')
+            LOG.warning('Can not insert breakpoint without gdb')
 
     def is_working(self):
         """
@@ -387,7 +395,7 @@ class LibvirtdSession(object):
         :param timeout: Max wait time
         :param step: Checking interval
         """
-        logging.debug('Waiting for %s to stop', self.service_exec)
+        LOG.debug('Waiting for %s to stop', self.service_exec)
         if self.gdb:
             return self.gdb.wait_for_stop(timeout=timeout)
         else:
@@ -403,11 +411,11 @@ class LibvirtdSession(object):
 
         :param timeout: Max wait time
         """
-        logging.debug('Waiting for %s to terminate', self.service_exec)
+        LOG.debug('Waiting for %s to terminate', self.service_exec)
         if self.gdb:
             return self.gdb.wait_for_termination(timeout=timeout)
         else:
-            logging.error("Only gdb session supports wait_for_termination.")
+            LOG.error("Only gdb session supports wait_for_termination.")
 
     def exit(self):
         """
@@ -428,9 +436,9 @@ def deprecation_warning():
     As the utils_libvirtd.libvirtd_xxx interfaces are deprecated,
     this function are printing the warning to user.
     """
-    logging.warning("This function was deprecated, Please use "
-                    "class utils_libvirtd.Libvirtd to manage "
-                    "libvirtd service.")
+    LOG.warning("This function was deprecated, Please use "
+                "class utils_libvirtd.Libvirtd to manage "
+                "libvirtd service.")
 
 
 def libvirtd_start():
