@@ -59,7 +59,7 @@ class Uri(object):
             hypervisor = "kvm"
         self.hyper = hypervisor
 
-    def get_uri(self, hostname, vpx_dc=None, esx_ip=None):
+    def get_uri(self, hostname, vpx_dc=None, esx_ip=None, username=None):
         """
         Uri dispatcher.
 
@@ -69,6 +69,7 @@ class Uri(object):
         self.host = hostname
         self.vpx_dc = vpx_dc
         self.esx_ip = esx_ip
+        self.username = username if username else 'root'
         return uri_func()
 
     def _get_kvm_uri(self):
@@ -91,11 +92,12 @@ class Uri(object):
         """
         uri = ''
         if self.vpx_dc and self.esx_ip:
-            uri = "vpx://root@%s/%s/%s/?no_verify=1" % (self.host,
-                                                        self.vpx_dc,
-                                                        self.esx_ip)
+            uri = "vpx://%s@%s/%s/%s/?no_verify=1" % (self.username,
+                                                      self.host,
+                                                      self.vpx_dc,
+                                                      self.esx_ip)
         if not self.vpx_dc and self.esx_ip:
-            uri = "esx://root@%s/?no_verify=1" % self.esx_ip
+            uri = "esx://%s@%s/?no_verify=1" % (self.username, self.esx_ip)
         return uri
 
     # add new hypervisor in here.
@@ -288,13 +290,22 @@ class Target(object):
                                 '%s/%s*' %
                                 (vddk_lib_rootdir, vddk_lib_prefix)))
                         for i in range(1, vddklib_count + 1):
+                            is_same = True
                             vddk_lib = '%s/%s' % (vddk_lib_rootdir,
                                                   vddk_lib_prefix + str(i))
-                            if all(
-                                compare_md5(
-                                    os.path.join(
-                                        mount_point, file_i), os.path.join(
-                                        vddk_lib, file_i)) for file_i in check_list):
+                            for file_i in check_list:
+                                src_file = os.path.join(mount_point, file_i)
+                                dst_file = os.path.join(vddk_lib, file_i)
+                                # skip the check if both don't have the file.
+                                if not os.path.exists(
+                                        src_file) and not os.path.exists(dst_file):
+                                    LOG.debug("Skip comparing file %s" % dst_file)
+                                    continue
+                                if not compare_md5(src_file, dst_file):
+                                    is_same = False
+                                    break
+
+                            if is_same:
                                 os.symlink(vddk_lib, vddk_libdir, True)
                                 break
 
@@ -419,7 +430,8 @@ class Target(object):
         """
         if not self.os_directory:
             base_image_dir = '/var/lib/libvirt/images'
-            self.os_directory = tempfile.mkdtemp(prefix='v2v_os_directory', dir=base_image_dir)
+            self.os_directory = tempfile.mkdtemp(
+                prefix='v2v_os_directory', dir=base_image_dir)
         # Pass the json directory to testcase for checking
         self.params.get('params').update({'os_directory': self.os_directory})
 
@@ -456,6 +468,12 @@ class Target(object):
         if rhv_upload_opts:
             options += ' %s' % rhv_upload_opts
 
+        has_rhv_proxy_ver = '[virt-v2v-1.45.99-1,)'
+        # Remove rhv-proxy option from cmd
+        if not multiple_versions_compare(has_rhv_proxy_ver) and '-oo rhv-proxy' in options:
+            rhv_proxy_option = "(-oo rhv-proxy=(\S+))\s*|(-oo rhv-proxy)(?!=)"
+            options = re.sub(rhv_proxy_option, '', options)
+
         return options
 
     def _get_local_options(self):
@@ -467,6 +485,15 @@ class Target(object):
 
         return options
 
+    def _get_qemu_options(self):
+        """
+        Construct output options for -o qemu
+        """
+        os_directory = self._get_os_directory()
+        options = " -os %s" % os_directory
+
+        return options
+
     def _get_null_options(self):
         """
         Construct output options for -o null
@@ -1302,13 +1329,14 @@ def v2v_cmd(params, auto_clean=True, cmd_only=False, interaction=False):
     params.update({'_v2v_virsh': None})
     # if 'has_rhv_disk_uuid' is 'yes', will append rhv-disk-uuid automatically.
     has_rhv_disk_uuid = params_get(params, 'has_rhv_disk_uuid')
+    vpx_username = params_get(params, 'vpx_username')
 
     uri_obj = Uri(hypervisor)
 
     # Return actual 'uri' according to 'hostname' and 'hypervisor'
     if src_uri_type == 'esx':
         vpx_dc = None
-    uri = uri_obj.get_uri(hostname, vpx_dc, esxi_host)
+    uri = uri_obj.get_uri(hostname, vpx_dc, esxi_host, vpx_username)
 
     try:
         # Pre-process for v2v
@@ -1958,7 +1986,7 @@ def multiple_versions_compare(interval):
 
     :param interval: An interval is a string representation of a
     """
-    re_pkg_name = r'(.*?)-(?=\d+\.?)+'
+    re_pkg_name = r',?(.*?)-(?=\d+\.?)+'
     versions = interval.split(';')
     # ';' is used to split multiple pkgs.
     for ver_i in versions:
@@ -2021,6 +2049,26 @@ def params_get(params, name, default=None):
         name, default) if 'params' in params else params.get(name, default))
 
 
+def set_libguestfs_backend(params):
+    """
+    A helper function to set LIBGUESTFS_BACKEND.
+    The default value is 'libvirt'.
+
+    :param params: A dictionary includes all of required parameters.
+    """
+    cmd = 'rpm -q virt-v2v'
+    libguestfs_backend = params_get(params, "libguestfs_backend")
+    hypervisor = params_get(params, "hypervisor")
+
+    if 'el8' in process.run(cmd, verbose=True, ignore_status=True).stdout_text and hypervisor == 'xen':
+        libguestfs_backend = 'direct'
+    if not libguestfs_backend:
+        libguestfs_backend = 'libvirt'
+
+    LOG.info('set LIBGUESTFS_BACKEND to %s', libguestfs_backend)
+    os.environ['LIBGUESTFS_BACKEND'] = libguestfs_backend
+
+
 def interactive_run(params, timeout=300, *args, **kwargs):
     """
     Run v2v command interactively.
